@@ -13,7 +13,7 @@ sc_vertex <- function(x, ...) {
 #' @name sc_vertex
 #' @export
 sc_vertex.default <- function(x, ...) {
-  SC(x)[["vertex"]]
+  SC0(x)[["vertex"]]
 }
 
 #' @name sc_vertex
@@ -21,9 +21,11 @@ sc_vertex.default <- function(x, ...) {
 sc_vertex.SC <- function(x, ...) {
   x[["vertex"]]
 }
-# sc_vertex.SC0 <- function(x, ...) {
-#   x[["vertex"]] %>% dplyr::mutate(vertex_ = dplyr::row_number())
-# }
+#' @name sc_vertex
+#' @export
+sc_vertex.SC0 <- function(x, ...) {
+  x[["vertex"]]
+}
 #' @name sc_vertex
 #' @export
 sc_vertex.ARC <- function(x, ...) {
